@@ -1,8 +1,8 @@
-## ----, echo=FALSE--------------------------------------------------------
+## ---- echo=FALSE---------------------------------------------------------
 knitr::opts_chunk$set(fig.width = 7, 
                       fig.height=3, dev='png', dev.args=list(type="cairo"))
 
-## ----, fig.height=4, fig.width=8, message=FALSE--------------------------
+## ---- fig.height=4, fig.width=8, message=FALSE---------------------------
 library(forestplot)
 # Cochrane data from the 'rmeta'-package
 cochrane_from_rmeta <- 
@@ -32,10 +32,10 @@ forestplot(tabletext,
            cochrane_from_rmeta,new_page = TRUE,
            is.summary=c(TRUE,TRUE,rep(FALSE,8),TRUE),
            clip=c(0.1,2.5), 
-           xlog=TRUE,
+           xlog=TRUE, 
            col=fpColors(box="royalblue",line="darkblue", summary="royalblue"))
 
-## ----, fig.height=4, fig.width=8, message=FALSE--------------------------
+## ---- fig.height=4, fig.width=8, message=FALSE---------------------------
 forestplot(tabletext, 
            hrzl_lines = gpar(col="#444444"),
            cochrane_from_rmeta,new_page = TRUE,
@@ -44,7 +44,7 @@ forestplot(tabletext,
            xlog=TRUE,
            col=fpColors(box="royalblue",line="darkblue", summary="royalblue"))
 
-## ----, fig.height=4, fig.width=8, message=FALSE--------------------------
+## ---- fig.height=4, fig.width=8, message=FALSE---------------------------
 forestplot(tabletext, 
            hrzl_lines = list("3" = gpar(lty=2), 
                              "11" = gpar(lwd=1, columns=1:4, col = "#000044")),
@@ -54,6 +54,17 @@ forestplot(tabletext,
            xlog=TRUE,
            col=fpColors(box="royalblue",line="darkblue", summary="royalblue", hrz_lines = "#444444"))
 
+## ---- fig.height=4, fig.width=8, message=FALSE---------------------------
+forestplot(tabletext, 
+           hrzl_lines = list("3" = gpar(lty=2), 
+                             "11" = gpar(lwd=1, columns=1:4, col = "#000044")),
+           cochrane_from_rmeta,new_page = TRUE,
+           is.summary=c(TRUE,TRUE,rep(FALSE,8),TRUE),
+           clip=c(0.1,2.5), 
+           xlog=TRUE,
+           col=fpColors(box="royalblue",line="darkblue", summary="royalblue", hrz_lines = "#444444"),
+           vertices = TRUE)
+
 ## ------------------------------------------------------------------------
 forestplot(tabletext, 
            graph.pos = 4,
@@ -72,7 +83,7 @@ clrs <- fpColors(box="royalblue",line="darkblue", summary="royalblue")
 tabletext <- 
   list(c(NA, rownames(HRQoL$Sweden)),
        append(list(expression(beta)), sprintf("%.2f", HRQoL$Sweden[,"coef"])))
-forestplot(tabletext, new_page = TRUE,
+forestplot(tabletext, 
            rbind(rep(NA, 3), 
                  HRQoL$Sweden),
            col=clrs,
@@ -130,7 +141,6 @@ forestplot(tabletext,
 
 ## ------------------------------------------------------------------------
 forestplot(tabletext, 
-            legend = c("Sweden", "Denmark"),
             fn.ci_norm = c(fpDrawNormalCI, fpDrawCircleCI),
             boxsize = .25, # We set the box size to better visualize the type
             line.margin = .1, # We need to add this to avoid crowding
@@ -138,9 +148,23 @@ forestplot(tabletext,
             lower = cbind(HRQoL$Sweden[, "lower"], HRQoL$Denmark[, "lower"]),
             upper = cbind(HRQoL$Sweden[, "upper"], HRQoL$Denmark[, "upper"]),
             clip =c(-.125, 0.075),
+            lty.ci = c(1, 2),
             col=fpColors(box=c("blue", "darkred")),
             xlab="EQ-5D index")
 
+## ------------------------------------------------------------------------
+forestplot(tabletext, 
+           legend = c("Sweden", "Denmark"),
+           fn.ci_norm = c(fpDrawNormalCI, fpDrawCircleCI),
+           boxsize = .25, # We set the box size to better visualize the type
+           line.margin = .1, # We need to add this to avoid crowding
+           mean = cbind(HRQoL$Sweden[, "coef"], HRQoL$Denmark[, "coef"]),
+           lower = cbind(HRQoL$Sweden[, "lower"], HRQoL$Denmark[, "lower"]),
+           upper = cbind(HRQoL$Sweden[, "upper"], HRQoL$Denmark[, "upper"]),
+           clip =c(-.125, 0.075),
+           col=fpColors(box=c("blue", "darkred")),
+           xlab="EQ-5D index")
+
 ## ------------------------------------------------------------------------
 forestplot(tabletext, 
            legend_args = fpLegend(pos = list(x=.85, y=0.25), 
@@ -156,3 +180,73 @@ forestplot(tabletext,
            col=fpColors(box=c("blue", "darkred")),
            xlab="EQ-5D index")
 
+## ------------------------------------------------------------------------
+forestplot(tabletext, 
+           legend = c("Sweden", "Denmark"),
+           fn.ci_norm = c(fpDrawNormalCI, fpDrawCircleCI),
+           boxsize = .25, # We set the box size to better visualize the type
+           line.margin = .1, # We need to add this to avoid crowding
+           mean = cbind(HRQoL$Sweden[, "coef"], HRQoL$Denmark[, "coef"]),
+           lower = cbind(HRQoL$Sweden[, "lower"], HRQoL$Denmark[, "lower"]),
+           upper = cbind(HRQoL$Sweden[, "upper"], HRQoL$Denmark[, "upper"]),
+           clip =c(-.125, 0.075),
+           col=fpColors(box=c("blue", "darkred")),
+           xticks = c(-.1, -0.05, 0, .05),
+           xlab="EQ-5D index")
+
+## ------------------------------------------------------------------------
+xticks <- seq(from = -.1, to = .05, by = 0.025)
+xtlab <- rep(c(TRUE, FALSE), length.out = length(xticks))
+attr(xticks, "labels") <- xtlab
+forestplot(tabletext, 
+           legend = c("Sweden", "Denmark"),
+           fn.ci_norm = c(fpDrawNormalCI, fpDrawCircleCI),
+           boxsize = .25, # We set the box size to better visualize the type
+           line.margin = .1, # We need to add this to avoid crowding
+           mean = cbind(HRQoL$Sweden[, "coef"], HRQoL$Denmark[, "coef"]),
+           lower = cbind(HRQoL$Sweden[, "lower"], HRQoL$Denmark[, "lower"]),
+           upper = cbind(HRQoL$Sweden[, "upper"], HRQoL$Denmark[, "upper"]),
+           clip =c(-.125, 0.075),
+           col=fpColors(box=c("blue", "darkred")),
+           xticks = xticks,
+           xlab="EQ-5D index")
+
+## ------------------------------------------------------------------------
+forestplot(tabletext, 
+           legend = c("Sweden", "Denmark"),
+           fn.ci_norm = c(fpDrawNormalCI, fpDrawCircleCI),
+           boxsize = .25, # We set the box size to better visualize the type
+           line.margin = .1, # We need to add this to avoid crowding
+           mean = cbind(HRQoL$Sweden[, "coef"], HRQoL$Denmark[, "coef"]),
+           lower = cbind(HRQoL$Sweden[, "lower"], HRQoL$Denmark[, "lower"]),
+           upper = cbind(HRQoL$Sweden[, "upper"], HRQoL$Denmark[, "upper"]),
+           clip =c(-.125, 0.075),
+           col=fpColors(box=c("blue", "darkred")),
+           grid = TRUE,
+           xticks = c(-.1, -0.05, 0, .05),
+           xlab="EQ-5D index")
+
+## ------------------------------------------------------------------------
+forestplot(tabletext, 
+           legend = c("Sweden", "Denmark"),
+           fn.ci_norm = c(fpDrawNormalCI, fpDrawCircleCI),
+           boxsize = .25, # We set the box size to better visualize the type
+           line.margin = .1, # We need to add this to avoid crowding
+           mean = cbind(HRQoL$Sweden[, "coef"], HRQoL$Denmark[, "coef"]),
+           lower = cbind(HRQoL$Sweden[, "lower"], HRQoL$Denmark[, "lower"]),
+           upper = cbind(HRQoL$Sweden[, "upper"], HRQoL$Denmark[, "upper"]),
+           clip =c(-.125, 0.075),
+           col=fpColors(box=c("blue", "darkred")),
+           grid = structure(c(-.1, -.05, .05), 
+                    gp = gpar(lty = 2, col = "#CCCCFF")), 
+           xlab="EQ-5D index")
+
+## ---- eval=FALSE, echo=TRUE----------------------------------------------
+#  grid_arg <- c(-.1, -.05, .05)
+#  attr(grid_arg, "gp") <- gpar(lty = 2, col = "#CCCCFF")
+#  
+#  identical(grid_arg,
+#            structure(c(-.1, -.05, .05),
+#                      gp = gpar(lty = 2, col = "#CCCCFF")))
+#  # Returns TRUE
+
